Name:          zsh
Version:       5.9
Release:       3mamba
Summary:       A shell designed for interactive use
Group:         Applications/Shells
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.zsh.org/
Source:        https://www.zsh.org/pub/zsh-%{version}.tar.xz
Patch0:        zsh-5.9-gcc-14.patch
Patch1:        zsh-5.9-do-not-use-egrep-in-tests.patch
Patch2:        zsh-5.9-use-int-main.patch
Patch3:        zsh-5.9-fix-autocompletion.patch
Patch4:        zsh-5.9-texinfo-7.0.patch
Patch5:        zsh-5.9-pcre2.patch
License:       MIT
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libcap-devel
BuildRequires: libgdbm-devel
BuildRequires: libncurses-devel
BuildRequires: libpcre2-devel
## AUTOBUILDREQ-END
Provides:      /bin/zsh

%description
Zsh is a shell designed for interactive use, although it is also a powerful scripting language. More information can be found on the "Zsh Web Pages" sites.

%debug_package

%prep
%setup -q
%patch 0 -p1 -b .gcc-14
%patch 1 -p1 -b .do-not-use-egrep-in-tests
%patch 2 -p1 -b .use-int-main
%patch 3 -p1 -b .fix-autocompletion
%patch 4 -p1 -b .texinfo-7.0
%patch 5 -p1 -F2 -b .pcre2

sed -i "s|/usr/local/bin/zsh|%{_bindir}/zsh|" ./Functions/VCS_Info/test-repo-git-rebase-*

# Fix usb.ids path
sed -i 's#/usr/share/misc/usb.ids#/usr/share/hwdata/usb.ids#g' Completion/Linux/Command/_lsusb

# Remove unneeded and conflicting completion scripts
for _fpath in AIX BSD Cygwin Darwin Debian Mandriva openSUSE Redhat Solaris; do
  rm -rf Completion/$_fpath
  sed "s#\s*Completion/$_fpath/\*/\*##g" -i Src/Zle/complete.mdd
done
rm Completion/Linux/Command/_pkgtool

autoreconf -f -i

%build
%configure \
   --bindir=%{_bindir} \
   --enable-etcdir=%{_sysconfdir}/zsh \
   --enable-zshenv=%{_sysconfdir}/zsh/zshenv \
   --enable-zlogin=%{_sysconfdir}/zsh/zlogin \
   --enable-zlogout=%{_sysconfdir}/zsh/zlogout \
   --enable-zprofile=%{_sysconfdir}/zsh/zprofile \
   --enable-zshrc=%{_sysconfdir}/zsh/zshrc \
   --enable-maildir-support \
   --with-term-lib='ncursesw' \
   --enable-multibyte \
   --enable-function-subdirs \
   --enable-fndir=%{_datadir}/zsh/functions \
   --enable-scriptdir=%{_datadir}/zsh/scripts \
   --enable-runhelpdir=%{_datadir}/zsh/help \
   --with-tcsetpgrp \
   --enable-pcre \
   --enable-gdbm \
   --enable-cap \
   --enable-zsh-secure-free

%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

for f in zlogin zshenv zshrc; do
   install -D -m0644 StartupFiles/$f %{buildroot}%{_sysconfdir}/zsh/$f
done

install -d -m0755 %{buildroot}%{_sysconfdir}/zsh/scripts

rm -f %{buildroot}%{_bindir}/zsh-%{version}

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/zsh
%config(noreplace) %{_sysconfdir}/zsh/zlogin
%config(noreplace) %{_sysconfdir}/zsh/zshenv
%config(noreplace) %{_sysconfdir}/zsh/zshrc
%{_bindir}/zsh
%dir %{_libdir}/zsh
%dir %{_libdir}/zsh/%{version}
%{_libdir}/zsh/%{version}/*
%dir %{_datadir}/zsh/functions
%{_datadir}/zsh/functions/*
%dir %{_datadir}/zsh/help
%{_datadir}/zsh/help/*
%dir %{_datadir}/zsh/scripts
%{_datadir}/zsh/scripts/newuser
%{_mandir}/man1/zsh*.1*
%doc LICENCE
#% doc ChangeLog NEWS README

%changelog
* Sun Oct 06 2024 Automatic Build System <autodist@openmamba.org> 5.9-3mamba
- rebuilt with updated configuration options

* Mon Sep 11 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 5.9-2mamba
- fix requirements for /usr/local/bin/zsh

* Fri May 20 2022 Automatic Build System <autodist@mambasoft.it> 5.9-1mamba
- automatic version update by autodist

* Sun Apr 24 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 5.8.1-2mamba
- rebuilt in %_bindir

* Mon Feb 14 2022 Automatic Build System <autodist@mambasoft.it> 5.8.1-1mamba
- automatic version update by autodist

* Tue Feb 25 2020 Automatic Build System <autodist@mambasoft.it> 5.8-1mamba
- automatic version update by autodist

* Mon Feb 04 2019 Automatic Build System <autodist@mambasoft.it> 5.7.1-1mamba
- automatic version update by autodist

* Tue Jan 29 2019 Automatic Build System <autodist@mambasoft.it> 5.7-1mamba
- automatic version update by autodist

* Sun Sep 16 2018 Automatic Build System <autodist@mambasoft.it> 5.6.2-1mamba
- automatic version update by autodist

* Fri Sep 14 2018 Automatic Build System <autodist@mambasoft.it> 5.6.1-1mamba
- automatic version update by autodist

* Thu Apr 19 2018 Automatic Build System <autodist@mambasoft.it> 5.5.1-1mamba
- automatic version update by autodist

* Fri Apr 13 2018 Automatic Build System <autodist@mambasoft.it> 5.5-1mamba
- automatic version update by autodist

* Thu Nov 30 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 5.4.2-1mamba
- package created using the webbuild interface
